local Vars = {}
local myName = "SaveMyBuild"
local LIBMWIN = LibStub:GetLibrary("LibMsgWin-1.0")
local myMsgWindow = {}

local function TestIt(buildName)

	for kSkill, vSkill in pairs(Vars[buildName].Skills) do
		d(kSkill)
	end
	
end

local function ShowData(buildName)

	local iSkillType = 0
	local iSkillLine = 0
	local iAbility = 0
	local iDiscipline = 0
	local iChampionAbility = 0
	
	if buildName == "" then
		d("Must supply a build name")
		return
	end
  
	if Vars[buildName] == nil then
		d("Cannot find build |cffffff" .. buildName)
		return
	end
	
	d("Loading build |cffffff" .. buildName)
	myMsgWindow:ClearText()
	myMsgWindow:SetHidden(false)
	
	msg = string.format("|cff00ff%s", Vars[buildName].Character.Name)
	myMsgWindow:AddText(msg)
	msg = string.format("|cffff00   %s", Vars[buildName].Character.Race)
	myMsgWindow:AddText(msg)
	msg = string.format("|cffff00   %s", Vars[buildName].Character.Class)
	myMsgWindow:AddText(msg)
	
	msg = string.format("|cff00ffAttributes")
	myMsgWindow:AddText(msg)
	msg = string.format("|cff0000   Health|cffffff: %s", Vars[buildName].Attributes.Health)
	myMsgWindow:AddText(msg)
	msg = string.format("|c0000ff   Magicka|cffffff: %s", Vars[buildName].Attributes.Magicka)
	myMsgWindow:AddText(msg)
	msg = string.format("|c00ff00   Stamina|cffffff: %s", Vars[buildName].Attributes.Stamina)
	myMsgWindow:AddText(msg)
	
	for iSkillType = 1, Vars[buildName].Skills.Count do
		for iSkillLine = 1, Vars[buildName].Skills[iSkillType].Count do
			if Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Count > 0 then
				msg = string.format("|cff00ff%s", Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Name)
				myMsgWindow:AddText(msg)
				for iAbility = 1, Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Count do
					if Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Abilities[iAbility].Current > 0 then
						msg = string.format("|cffff00   %s |cffffff(%d/%d)", Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Abilities[iAbility].Name, Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Abilities[iAbility].Current, Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Abilities[iAbility].Max)
					else
						msg = string.format("|cffff00   %s", Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Abilities[iAbility].Name)
					end
					myMsgWindow:AddText(msg)
				end
			end
		end
	end
	
	for iDiscipline = 1, Vars[buildName].Disciplines.Count do
		if Vars[buildName].Disciplines[iDiscipline].Count > 0 then
			msg = string.format("|cff00ff%s", Vars[buildName].Disciplines[iDiscipline].Name)
			myMsgWindow:AddText(msg)
			for iChampionAbility = 1, Vars[buildName].Disciplines[iDiscipline].Count do
				msg = string.format("|cffff00   %s|cffffff: %d", Vars[buildName].Disciplines[iDiscipline].Abilities[iChampionAbility].Name, Vars[buildName].Disciplines[iDiscipline].Abilities[iChampionAbility].Points)
				myMsgWindow:AddText(msg)
			end
		end
	end
	
end
local function SaveData(buildName)

	local iSkillType = 0
	local iSkillLine = 0
	local iAbility = 0
	local iDiscipline = 0
	local iChampionAbility = 0
	local nSkillTypes = 0
	local nSkillLines = 0
	local nAbilities = 0
	local nDisciplines = 0
	local nChampionAbilities = 0
	
	if buildName == "" then
		d("Must supply a build name")
		return
	end
	
	if Vars[buildName] == nil then
		Vars[buildName] = {}
	end

	Vars[buildName].Character = {}
	Vars[buildName].Character.Name = GetUnitName("player")
	Vars[buildName].Character.Race = GetUnitRace("player")
	Vars[buildName].Character.Class = GetUnitClass("player")
	
	Vars[buildName].Attributes = {}
	Vars[buildName].Attributes.Health = GetAttributeSpentPoints(ATTRIBUTE_HEALTH)
	Vars[buildName].Attributes.Magicka = GetAttributeSpentPoints(ATTRIBUTE_MAGICKA)
	Vars[buildName].Attributes.Stamina = GetAttributeSpentPoints(ATTRIBUTE_STAMINA)

	Vars[buildName].Skills = {}
	
	for iSkillType = 1, GetNumSkillTypes() do
		Vars[buildName].Skills[iSkillType] = {}
		nSkillTypes = nSkillTypes + 1
		Vars[buildName].Skills[iSkillType].SkillLines = {}
		nSkillLines = 0
		for iSkillLine = 1, GetNumSkillLines(iSkillType) do
			Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine] = {}
			nSkillLines = nSkillLines + 1
			Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Name = GetSkillLineInfo(iSkillType, iSkillLine)
			Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Abilities = {}
			nAbilities = 0
			for iAbility = 1, GetNumSkillAbilities(iSkillType, iSkillLine) do
				local Name, Texture, Rank, Passive, Ultimate, Purchased, Progression = GetSkillAbilityInfo(iSkillType, iSkillLine, iAbility)
				if Purchased then
					nAbilities = nAbilities + 1
					Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Abilities[nAbilities] = {}
					Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Abilities[nAbilities].Name = Name
					local Cur = 0
					local Max = 0
					if Passive then
						Cur, Max = GetSkillAbilityUpgradeInfo(iSkillType, iSkillLine, iAbility)
						if Cur == nil then Cur = 0 end
						if Max == nil then Max = 0 end
					end
					Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Abilities[nAbilities].Max = Max
					Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Abilities[nAbilities].Current = Cur
				end
			end
			Vars[buildName].Skills[iSkillType].SkillLines[iSkillLine].Count = nAbilities
		end	
		Vars[buildName].Skills[iSkillType].Count = nSkillLines
	end
	Vars[buildName].Skills.Count = nSkillTypes
	
	Vars[buildName].Disciplines = {}
	
	for iDiscipline = 1, GetNumChampionDisciplines() do
		nDisciplines = nDisciplines + 1
		Vars[buildName].Disciplines[iDiscipline] = {}
		Vars[buildName].Disciplines[iDiscipline].Name = GetChampionDisciplineName(iDiscipline)
		Vars[buildName].Disciplines[iDiscipline].Abilities = {}
		nChampionAbilities = 0
		for iChampionAbility = 1, GetNumChampionDisciplineSkills(iDiscipline) do
			if GetNumPointsSpentOnChampionSkill(iDiscipline, iChampionAbility) > 0 then
				nChampionAbilities = nChampionAbilities + 1
				Vars[buildName].Disciplines[iDiscipline].Abilities[nChampionAbilities] = {}
				Vars[buildName].Disciplines[iDiscipline].Abilities[nChampionAbilities].Name = GetChampionSkillName(iDiscipline, iChampionAbility)
				Vars[buildName].Disciplines[iDiscipline].Abilities[nChampionAbilities].Points = GetNumPointsSpentOnChampionSkill(iDiscipline, iChampionAbility)
			end
		end
		Vars[buildName].Disciplines[iDiscipline].Count = nChampionAbilities
	end
	Vars[buildName].Disciplines.Count = nDisciplines
	
end

local function OnAddOnLoaded(event, addonName)

	if addonName == myName then
		Vars = ZO_SavedVars:NewAccountWide("SaveMyBuild_Vars", 1)
		
		myMsgWindow = LIBMWIN:CreateMsgWindow("SaveMyBuild", "Saved Character Stats")
		myMsgWindow:SetHidden(true)
		local closeButton = WINDOW_MANAGER:CreateControl("SaveMyBuild_Close", myMsgWindow , CT_BUTTON)
		closeButton:SetDimensions(20,20)
		closeButton:SetAnchor(TOPRIGHT, myMsgWindow, TOPRIGHT,0,0)
		closeButton:SetFont("ZoFontGameOutline")
		closeButton:SetText("X")
		closeButton:SetHandler("OnClicked",function(self,but)
			myMsgWindow:ClearText()
			myMsgWindow:SetHidden(true)
		end)
		myMsgWindow:SetWidth(myMsgWindow:GetWidth() * 2)
		myMsgWindow:SetHeight(myMsgWindow:GetHeight() * 2.5)
		
		SLASH_COMMANDS["/savebuild"] = SaveData
		SLASH_COMMANDS["/showbuild"] = ShowData
		SLASH_COMMANDS["/testit"] = TestIt
		
	end
	
end

EVENT_MANAGER:RegisterForEvent(myName, EVENT_ADD_ON_LOADED, OnAddOnLoaded)